pub type HandlerList = Vec<HandlerFunc>;Expand description
A type alias for a list of handler functions.
Aliased Type
pub struct HandlerList { /* private fields */ }pub type HandlerList = Vec<HandlerFunc>;A type alias for a list of handler functions.
pub struct HandlerList { /* private fields */ }